@@ -1,5 +1,6 @@
 """Provides Authentication and Authorization classes."""
 import aiohttp
+import inspect
 import time
 
 from aiohttp import ClientRequest
@@ -51,8 +52,9 @@ class BaseAuthenticator(object):
             is set to ``True``.
         :param scopes: A list of OAuth scopes to request authorization for.
         :param state: A string that will be reflected in the callback to
-            ``redirect_uri``. This value should be temporarily unique to the
-            client for whom the URL was generated for.
+            ``redirect_uri``. Elements must be printable ASCII characters in the range
+            0x20 through 0x7E inclusive. This value should be temporarily unique to the
+            client for whom the URL was generated.
         :param implicit: (optional) Use the implicit grant flow (default:
             False). This flow is only available for UntrustedAuthenticators.
 
@@ -193,16 +195,35 @@ class Authorizer(BaseAuthorizer):
 
     AUTHENTICATOR_CLASS = BaseAuthenticator
 
-    def __init__(self, authenticator, refresh_token=None):
+    def __init__(
+        self,
+        authenticator,
+        *,
+        post_refresh_callback=None,
+        pre_refresh_callback=None,
+        refresh_token=None,
+    ):
         """Represent a single authorization to Reddit's API.
 
         :param authenticator: An instance of a subclass of
             :class:`BaseAuthenticator`.
+        :param post_refresh_callback: (Optional) When a single-argument synchronous or
+            asynchronous function is passed, the function will be called prior to
+            refreshing the access and refresh tokens. The argument to the callback is
+            the :class:`Authorizer` instance. This callback can be used to inspect and
+            modify the attributes of the :class:`Authorizer`.
+        :param pre_refresh_callback: (Optional) When a single-argument function
+            synchronous or asynchronous is passed, the function will be called after
+            refreshing the access and refresh tokens. The argument to the callback is
+            the :class:`Authorizer` instance. This callback can be used to inspect and
+            modify the attributes of the :class:`Authorizer`.
         :param refresh_token: (Optional) Enables the ability to refresh the
             authorization.
 
         """
         super(Authorizer, self).__init__(authenticator)
+        self._post_refresh_callback = post_refresh_callback
+        self._pre_refresh_callback = pre_refresh_callback
         self.refresh_token = refresh_token
 
     async def authorize(self, code):
@@ -222,11 +243,21 @@ class Authorizer(BaseAuthorizer):
 
     async def refresh(self):
         """Obtain a new access token from the refresh_token."""
+        if self._pre_refresh_callback:
+            if inspect.iscoroutinefunction(self._pre_refresh_callback):
+                await self._pre_refresh_callback(self)
+            else:
+                self._pre_refresh_callback(self)
         if self.refresh_token is None:
             raise InvalidInvocation("refresh token not provided")
         await self._request_token(
             grant_type="refresh_token", refresh_token=self.refresh_token
         )
+        if self._post_refresh_callback:
+            if inspect.iscoroutinefunction(self._post_refresh_callback):
+                await self._post_refresh_callback(self)
+            else:
+                self._post_refresh_callback(self)
 
     async def revoke(self, only_access=False):
         """Revoke the current Authorization.
