@@ -25,7 +25,7 @@ class Requestor(object):
         """Create an instance of the Requestor class.
 
         :param user_agent: The user-agent for your application. Please follow reddit's
-            user-agent guidlines: https://github.com/reddit/reddit/wiki/API#rules
+            user-agent guidelines: https://github.com/reddit/reddit/wiki/API#rules
         :param oauth_url: (Optional) The URL used to make OAuth requests to the reddit
             site. (Default: https://oauth.reddit.com)
         :param reddit_url: (Optional) The URL used when obtaining access tokens.
@@ -36,19 +36,17 @@ class Requestor(object):
         """
         if user_agent is None or len(user_agent) < 7:
             raise InvalidInvocation("user_agent is not descriptive")
-        self.loop = loop or asyncio.get_event_loop()
-        self.set_http(session)
-        self._http._default_headers[
-            "User-Agent"
-        ] = f"{user_agent} asyncprawcore/{__version__}"
-        self.oauth_url = oauth_url
-        self.reddit_url = reddit_url
 
-    def set_http(self, session):
-        """Set the http session."""
+        self.loop = loop or asyncio.get_event_loop()
         self._http = session or aiohttp.ClientSession(
             loop=self.loop, timeout=aiohttp.ClientTimeout(total=None)
         )
+        self._http._default_headers[
+            "User-Agent"
+        ] = f"{user_agent} asyncprawcore/{__version__}"
+
+        self.oauth_url = oauth_url
+        self.reddit_url = reddit_url
 
     async def close(self):
         """Call close on the underlying session."""
